package com.rjconsultores.ventaboletos.web.gui.controladores.catalogos;

import java.util.HashMap;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zk.ui.event.EventListener;
import org.zkoss.zul.Messagebox;
import org.zkoss.zul.Paging;
import org.zkoss.zul.Textbox;

import com.rjconsultores.ventaboletos.entidad.Curso;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.HibernateSearchObject;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.PagedListWrapper;
import com.rjconsultores.ventaboletos.web.utilerias.render.RenderCurso;

@Controller("busquedaCursoController")
@Scope("prototype")
public class BusquedaCursoController extends MyGenericForwardComposer {

	private static final long serialVersionUID = 1L;
	@Autowired
	private transient PagedListWrapper<Curso> plwCurso;
	private MyListbox CursoList;
	private Paging pagingCurso;
	private Textbox txtNombre;

	@Override
	public void doAfterCompose(Component comp) throws Exception {

		super.doAfterCompose(comp);

		CursoList.setItemRenderer(new RenderCurso());
		CursoList.addEventListener("onDoubleClick", new EventListener() {

			@Override
			public void onEvent(Event event) throws Exception {
				Curso curso = (Curso) CursoList.getSelected();
				verCurso(curso);
			}
		});

		refreshLista();

		txtNombre.focus();
	}

	@SuppressWarnings({ "rawtypes", "unchecked" })
	private void verCurso(Curso e) {
		if (e == null) {
			return;
		}

		Map args = new HashMap();
		args.put("curso", e);
		args.put("cursoList", CursoList);

		openWindow("/gui/catalogos/editarCurso.zul",
				Labels.getLabel("editarCursoController.window.title"), args, MODAL);
	}

	private void refreshLista() throws InterruptedException {
		HibernateSearchObject<Curso> CursoBusqueda =
				new HibernateSearchObject<Curso>(Curso.class, pagingCurso.getPageSize());

		CursoBusqueda.addFilterLike("nomcurso", "%" + txtNombre.getText().trim().concat("%"));

		CursoBusqueda.addFilterEqual(ACTIVO, Boolean.TRUE);
		CursoBusqueda.addSortAsc("nomcurso");
		CursoBusqueda.addFilterNotEqual("cursoId", -1);

		plwCurso.init(CursoBusqueda, CursoList, pagingCurso);

		if (CursoList.getData().length == 0) {
			Messagebox.show(
					Labels.getLabel("MSG.ningunRegistro"),
					Labels.getLabel("busquedaCursoController.window.title"),
					Messagebox.OK, Messagebox.INFORMATION);
		}
	}

	public void onClick$btnRefresh(Event ev) throws InterruptedException {
		refreshLista();
	}

	public void onClick$btnPesquisa(Event ev) throws InterruptedException {
		refreshLista();
	}

	public void onClick$btnNovo(Event ev) throws InterruptedException {
		verCurso(new Curso());
	}
}
